==> apache-cassandra-2.2.19-src.tar.gz: apache-cassandra-2.2.19-src/src/java/org/apache/cassandra/serializers/EmptySerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.serializers;

import org.apache.cassandra.utils.ByteBufferUtil;

import java.nio.ByteBuffer;

public class EmptySerializer implements TypeSerializer<Void>
{
    public static final EmptySerializer instance = new EmptySerializer();

    public Void deserialize(ByteBuffer bytes)
    {
        return null;
    }

    public ByteBuffer serialize(Void value)
    {
        return ByteBufferUtil.EMPTY_BYTE_BUFFER;
    }

    public void validate(ByteBuffer bytes) throws MarshalException
    {
        if (bytes.remaining() > 0)
            throw new MarshalException("EmptyType only accept empty values");
    }

    public String toString(Void value)
    {
        return "";
    }

    public Class<Void> getType()
    {
        return Void.class;
    }
}

==> apache-cassandra-3.11.19-src.tar.gz: apache-cassandra-3.11.19-src/src/java/org/apache/cassandra/serializers/EmptySerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.serializers;

import org.apache.cassandra.utils.ByteBufferUtil;

import java.nio.ByteBuffer;

public class EmptySerializer implements TypeSerializer<Void>
{
    public static final EmptySerializer instance = new EmptySerializer();

    public Void deserialize(ByteBuffer bytes)
    {
        validate(bytes);
        return null;
    }

    public ByteBuffer serialize(Void value)
    {
        return ByteBufferUtil.EMPTY_BYTE_BUFFER;
    }

    public void validate(ByteBuffer bytes) throws MarshalException
    {
        if (bytes.remaining() > 0)
        {
            throw new MarshalException("EmptyType only accept empty values. " +
                                       "A non-empty value can be a result of a Thrift write into CQL-created dense table. " +
                                       "See CASSANDRA-15778 for details.");
        }
    }

    public String toString(Void value)
    {
        return "";
    }

    public Class<Void> getType()
    {
        return Void.class;
    }
}
